==> h3-3.6.1-he025d50_0.tar.bz2: Library/lib/cmake/h3/h3Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "h3::h3" for configuration "Release"
set_property(TARGET h3::h3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/h3.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3 "${_IMPORT_PREFIX}/lib/h3.lib" )

# Import target "h3::geoToH3" for configuration "Release"
set_property(TARGET h3::geoToH3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::geoToH3 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/geoToH3.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::geoToH3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::geoToH3 "${_IMPORT_PREFIX}/bin/geoToH3.exe" )

# Import target "h3::h3ToComponents" for configuration "Release"
set_property(TARGET h3::h3ToComponents APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToComponents PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToComponents.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToComponents )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToComponents "${_IMPORT_PREFIX}/bin/h3ToComponents.exe" )

# Import target "h3::h3ToGeo" for configuration "Release"
set_property(TARGET h3::h3ToGeo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeo.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeo )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeo "${_IMPORT_PREFIX}/bin/h3ToGeo.exe" )

# Import target "h3::h3ToLocalIj" for configuration "Release"
set_property(TARGET h3::h3ToLocalIj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToLocalIj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToLocalIj.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToLocalIj )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToLocalIj "${_IMPORT_PREFIX}/bin/h3ToLocalIj.exe" )

# Import target "h3::localIjToH3" for configuration "Release"
set_property(TARGET h3::localIjToH3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::localIjToH3 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/localIjToH3.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::localIjToH3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::localIjToH3 "${_IMPORT_PREFIX}/bin/localIjToH3.exe" )

# Import target "h3::h3ToGeoBoundary" for configuration "Release"
set_property(TARGET h3::h3ToGeoBoundary APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeoBoundary PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeoBoundary.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeoBoundary )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeoBoundary "${_IMPORT_PREFIX}/bin/h3ToGeoBoundary.exe" )

# Import target "h3::hexRange" for configuration "Release"
set_property(TARGET h3::hexRange APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::hexRange PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/hexRange.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::hexRange )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::hexRange "${_IMPORT_PREFIX}/bin/hexRange.exe" )

# Import target "h3::kRing" for configuration "Release"
set_property(TARGET h3::kRing APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::kRing PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/kRing.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::kRing )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::kRing "${_IMPORT_PREFIX}/bin/kRing.exe" )

# Import target "h3::h3ToGeoBoundaryHier" for configuration "Release"
set_property(TARGET h3::h3ToGeoBoundaryHier APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeoBoundaryHier PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeoBoundaryHier.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeoBoundaryHier )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeoBoundaryHier "${_IMPORT_PREFIX}/bin/h3ToGeoBoundaryHier.exe" )

# Import target "h3::h3ToGeoHier" for configuration "Release"
set_property(TARGET h3::h3ToGeoHier APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeoHier PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeoHier.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeoHier )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeoHier "${_IMPORT_PREFIX}/bin/h3ToGeoHier.exe" )

# Import target "h3::h3ToHier" for configuration "Release"
set_property(TARGET h3::h3ToHier APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToHier PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToHier.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToHier )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToHier "${_IMPORT_PREFIX}/bin/h3ToHier.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> h3-3.6.3-he025d50_0.tar.bz2: Library/lib/cmake/h3/h3Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "h3::h3" for configuration "Release"
set_property(TARGET h3::h3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3 PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/h3.lib"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3 "${_IMPORT_PREFIX}/lib/h3.lib" "${_IMPORT_PREFIX}/bin/h3.dll" )

# Import target "h3::geoToH3" for configuration "Release"
set_property(TARGET h3::geoToH3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::geoToH3 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/geoToH3.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::geoToH3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::geoToH3 "${_IMPORT_PREFIX}/bin/geoToH3.exe" )

# Import target "h3::h3ToComponents" for configuration "Release"
set_property(TARGET h3::h3ToComponents APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToComponents PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToComponents.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToComponents )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToComponents "${_IMPORT_PREFIX}/bin/h3ToComponents.exe" )

# Import target "h3::h3ToGeo" for configuration "Release"
set_property(TARGET h3::h3ToGeo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeo.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeo )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeo "${_IMPORT_PREFIX}/bin/h3ToGeo.exe" )

# Import target "h3::h3ToLocalIj" for configuration "Release"
set_property(TARGET h3::h3ToLocalIj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToLocalIj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToLocalIj.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToLocalIj )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToLocalIj "${_IMPORT_PREFIX}/bin/h3ToLocalIj.exe" )

# Import target "h3::localIjToH3" for configuration "Release"
set_property(TARGET h3::localIjToH3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::localIjToH3 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/localIjToH3.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::localIjToH3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::localIjToH3 "${_IMPORT_PREFIX}/bin/localIjToH3.exe" )

# Import target "h3::h3ToGeoBoundary" for configuration "Release"
set_property(TARGET h3::h3ToGeoBoundary APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeoBoundary PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeoBoundary.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeoBoundary )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeoBoundary "${_IMPORT_PREFIX}/bin/h3ToGeoBoundary.exe" )

# Import target "h3::hexRange" for configuration "Release"
set_property(TARGET h3::hexRange APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::hexRange PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/hexRange.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::hexRange )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::hexRange "${_IMPORT_PREFIX}/bin/hexRange.exe" )

# Import target "h3::kRing" for configuration "Release"
set_property(TARGET h3::kRing APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::kRing PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/kRing.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::kRing )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::kRing "${_IMPORT_PREFIX}/bin/kRing.exe" )

# Import target "h3::h3ToGeoBoundaryHier" for configuration "Release"
set_property(TARGET h3::h3ToGeoBoundaryHier APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeoBoundaryHier PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeoBoundaryHier.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeoBoundaryHier )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeoBoundaryHier "${_IMPORT_PREFIX}/bin/h3ToGeoBoundaryHier.exe" )

# Import target "h3::h3ToGeoHier" for configuration "Release"
set_property(TARGET h3::h3ToGeoHier APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToGeoHier PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToGeoHier.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToGeoHier )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToGeoHier "${_IMPORT_PREFIX}/bin/h3ToGeoHier.exe" )

# Import target "h3::h3ToHier" for configuration "Release"
set_property(TARGET h3::h3ToHier APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(h3::h3ToHier PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/h3ToHier.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS h3::h3ToHier )
list(APPEND _IMPORT_CHECK_FILES_FOR_h3::h3ToHier "${_IMPORT_PREFIX}/bin/h3ToHier.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
